# (yet another) RKI Scraper

The RKI is the abbreviation for the German Robert Koch Institut. They are the
central science organisation consulting the German government in health issues.

They also track (count) all sick and deceased persons.

This package shall provide sick and deceased person counts for all German States
(Bundesländer) and Counties (Landkreise).
